@@ -4,11 +4,13 @@ use strict;
 use warnings;
 use Test::More;
 use t::Utils;
-eval "use Test::postgresql";
-plan skip_all => "Test::postgresql required" if $@;
+use Test::Requires {
+    'DBD::Pg' => '0',
+    'Test::PostgreSQL' => '1.00'
+};
 
-my $pgsql = Test::postgresql->new
-    or plan skip_all => $Test::postgresql::errstr;
+my $pgsql = Test::PostgreSQL->new
+    or plan skip_all => $Test::PostgreSQL::errstr;
 
 {
     no warnings "redefine";
